@@ -2,6 +2,10 @@
 #define SXEVAL_VALUE_HPP
 
 #include "sxeval/AOperand.hpp"
+#include <string>
+
+
+/* DEFINITIONS */
 
 namespace sxeval {
 
@@ -10,6 +14,9 @@ class Value : public AOperand<T> {
 public:
     inline Value(T val) : AOperand<T>(_val), _val(val) {}
 
+    inline std::string toString() const override {
+        return std::to_string(_val); }
+
 private:
     T _val;
 
